@@ -30,9 +30,8 @@ from .operator_utils import set_sample_weight
 from sklearn.utils import indexable
 from sklearn.metrics import check_scoring
 from sklearn.model_selection._validation import _fit_and_score
-from sklearn.model_selection._split import check_cv
 
-from sklearn.base import clone, is_classifier
+from sklearn.base import clone
 from collections import defaultdict
 import warnings
 from stopit import threading_timeoutable, TimeoutException
@@ -231,16 +230,13 @@ def eaMuPlusLambda(population, toolbox, mu, lambda_, cxpb, mutpb, ngen, pbar,
 
     # Begin the generational process
     for gen in range(1, ngen + 1):
-        # after each population save a periodic pipeline
-        if per_generation_function is not None:
-            per_generation_function(gen)
         # Vary the population
         offspring = varOr(population, toolbox, lambda_, cxpb, mutpb)
 
 
         # Update generation statistic for all individuals which have invalid 'generation' stats
         # This hold for individuals that have been altered in the varOr function
-        for ind in population:
+        for ind in offspring:
             if ind.statistics['generation'] == 'INVALID':
                 ind.statistics['generation'] = gen
 
@@ -256,20 +252,19 @@ def eaMuPlusLambda(population, toolbox, mu, lambda_, cxpb, mutpb, ngen, pbar,
         if not pbar.disable:
             # Print only the best individual fitness
             if verbose == 2:
-                high_score = max([halloffame.keys[x].wvalues[1] for x in range(len(halloffame.keys))])
-                pbar.write('Generation {0} - Current best internal CV score: {1}'.format(gen, high_score))
+                high_score = max(halloffame.keys[x].wvalues[1] for x in range(len(halloffame.keys)))
+                pbar.fp.write('\nGeneration {0} - Current best internal CV score: {1}'.format(gen, high_score))
 
             # Print the entire Pareto front
             elif verbose == 3:
-                pbar.write('Generation {} - Current Pareto front scores:'.format(gen))
+                pbar.fp.write('\nGeneration {} - Current Pareto front scores:'.format(gen))
                 for pipeline, pipeline_scores in zip(halloffame.items, reversed(halloffame.keys)):
-                    pbar.write('{}\t{}\t{}'.format(
+                    pbar.fp.write('\n{}\t{}\t{}'.format(
                             int(pipeline_scores.wvalues[0]),
                             pipeline_scores.wvalues[1],
                             pipeline
                         )
                     )
-                pbar.write('')
 
         # after each population save a periodic pipeline
         if per_generation_function is not None:
@@ -394,11 +389,8 @@ def _wrapped_cross_val_score(sklearn_pipeline, features, target,
     target : array-like, optional, default: None
         The target variable to try to predict in the case of
         supervised learning.
-    cv: int or cross-validation generator
-        If CV is a number, then it is the number of folds to evaluate each
-        pipeline over in k-fold cross-validation during the TPOT optimization
-         process. If it is an object then it is an object to be used as a
-         cross-validation generator.
+    cv: cross-validation generator
+        Object to be used as a cross-validation generator.
     scoring_function : callable
         A scorer callable object / function with signature
         ``scorer(estimator, X, y)``.
@@ -413,7 +405,6 @@ def _wrapped_cross_val_score(sklearn_pipeline, features, target,
 
     features, target, groups = indexable(features, target, groups)
 
-    cv = check_cv(cv, target, classifier=is_classifier(sklearn_pipeline))
     cv_iter = list(cv.split(features, target, groups))
     scorer = check_scoring(sklearn_pipeline, scoring=scoring_function)
 
